<?php
namespace NL\NlMenubuilder\Domain\Model;


/***
 *
 * This file is part of the "Menu Builder" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 *  (c) 2021 
 *
 ***/
/**
 * Menu
 */
class Menu extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity
{

    /**
     * Name of the menu
     * 
     * @var string
     * @TYPO3\CMS\Extbase\Annotation\Validate("NotEmpty")
     */
    protected $title = '';

    /**
     * menuGroup
     * 
     * @var \NL\NlMenubuilder\Domain\Model\MenuGroup
     */
    protected $menuGroup = null;

    /**
     * menuItem
     * 
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\MenuItem>
     * @TYPO3\CMS\Extbase\Annotation\ORM\Cascade("remove")
     */
    protected $menuItem = null;

    /**
     * Returns the title
     * 
     * @return string $title
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Sets the title
     * 
     * @param string $title
     * @return void
     */
    public function setTitle($title)
    {
        $this->title = $title;
    }

    /**
     * __construct
     */
    public function __construct()
    {

        //Do not remove the next line: It would break the functionality
        $this->initStorageObjects();
    }

    /**
     * Initializes all ObjectStorage properties
     * Do not modify this method!
     * It will be rewritten on each save in the extension builder
     * You may modify the constructor of this class instead
     * 
     * @return void
     */
    protected function initStorageObjects()
    {
        $this->menuItem = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
    }

    /**
     * Returns the menuGroup
     * 
     * @return \NL\NlMenubuilder\Domain\Model\MenuGroup menuGroup
     */
    public function getMenuGroup()
    {
        return $this->menuGroup;
    }

    /**
     * Sets the menuGroup
     * 
     * @param \NL\NlMenubuilder\Domain\Model\MenuGroup $menuGroup
     * @return void
     */
    public function setMenuGroup(\NL\NlMenubuilder\Domain\Model\MenuGroup $menuGroup)
    {
        $this->menuGroup = $menuGroup;
    }

    /**
     * Adds a MenuItem
     * 
     * @param \NL\NlMenubuilder\Domain\Model\MenuItem $menuItem
     * @return void
     */
    public function addMenuItem(\NL\NlMenubuilder\Domain\Model\MenuItem $menuItem)
    {
        $this->menuItem->attach($menuItem);
    }

    /**
     * Removes a MenuItem
     * 
     * @param \NL\NlMenubuilder\Domain\Model\MenuItem $menuItemToRemove The MenuItem to be removed
     * @return void
     */
    public function removeMenuItem(\NL\NlMenubuilder\Domain\Model\MenuItem $menuItemToRemove)
    {
        $this->menuItem->detach($menuItemToRemove);
    }

    /**
     * Returns the menuItem
     * 
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\MenuItem> menuItem
     */
    public function getMenuItem()
    {
        return $this->menuItem;
    }

    /**
     * Sets the menuItem
     * 
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\MenuItem> $menuItem
     * @return void
     */
    public function setMenuItem(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $menuItem)
    {
        $this->menuItem = $menuItem;
    }
}
