<?php

namespace NL\NlMenubuilder\Domain\Model;

/***
 *
 * This file is part of the "Menu Builder" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 *  (c) 2021
 *
 ***/
/**
 * MenuItem
 */
class MenuItem extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity
{
    const TYPE_PAGE = 0;
    const TYPE_LINK = 1;
    const TYPE_CONTENT = 2;
    const TYPE_SUBMENU = 3;

    /**
     * Type of the menu item
     *
     * @var int
     * @TYPO3\CMS\Extbase\Annotation\Validate("NotEmpty")
     */
    protected $type = 0;

    /**
     * Name of the menu item
     *
     * @var string
     * @TYPO3\CMS\Extbase\Annotation\Validate("NotEmpty")
     */
    protected $title = '';

    /**
     * subtitle
     *
     * @var string
     */
    protected $subtitle = '';

    /**
     * Optional link image
     *
     * @var \TYPO3\CMS\Extbase\Domain\Model\FileReference
     * @TYPO3\CMS\Extbase\Annotation\ORM\Cascade("remove")
     */
    protected $image = null;

    /**
     * page
     *
     * @var string
     */
    protected $page = '';

    /**
     * link
     *
     * @var string
     */
    protected $link = '';

    /**
     * content
     *
     * @var string
     */
    protected $content = '';

    /**
     * submenu
     *
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\Menu>
     * @TYPO3\CMS\Extbase\Annotation\ORM\Cascade("remove")
     */
    protected $submenu = null;

    /**
     * Get type name of the menu item.
     *
     * @return string
     */
    public function getTypeName(): string
    {
        switch ($this->type) {
            case self::TYPE_PAGE:
                return 'Page';
            case self::TYPE_LINK:
                return 'Link';
            case self::TYPE_CONTENT:
                return 'Content';
            case self::TYPE_SUBMENU:
                return 'Submenu';
        }

        return 'Undefined';
    }

    /**
     * Returns the title
     *
     * @return string $title
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Sets the title
     *
     * @param string $title
     * @return void
     */
    public function setTitle($title)
    {
        $this->title = $title;
    }

    /**
     * Returns the type
     *
     * @return int $type
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Sets the type
     *
     * @param int $type
     * @return void
     */
    public function setType($type)
    {
        $this->type = $type;
    }

    /**
     * Returns the subtitle
     *
     * @return string $subtitle
     */
    public function getSubtitle()
    {
        return $this->subtitle;
    }

    /**
     * Sets the subtitle
     *
     * @param string $subtitle
     * @return void
     */
    public function setSubtitle($subtitle)
    {
        $this->subtitle = $subtitle;
    }

    /**
     * Returns the image
     *
     * @return \TYPO3\CMS\Extbase\Domain\Model\FileReference $image
     */
    public function getImage()
    {
        return $this->image;
    }

    /**
     * Sets the image
     *
     * @param \TYPO3\CMS\Extbase\Domain\Model\FileReference $image
     * @return void
     */
    public function setImage(\TYPO3\CMS\Extbase\Domain\Model\FileReference $image)
    {
        $this->image = $image;
    }

    /**
     * Returns the page
     *
     * @return string $page
     */
    public function getPage()
    {
        return $this->page;
    }

    /**
     * Sets the page
     *
     * @param string $page
     * @return void
     */
    public function setPage($page)
    {
        $this->page = $page;
    }

    /**
     * Returns the link
     *
     * @return string $link
     */
    public function getLink()
    {
        return $this->link;
    }

    /**
     * Sets the link
     *
     * @param string $link
     * @return void
     */
    public function setLink($link)
    {
        $this->link = $link;
    }

    /**
     * Returns the content
     *
     * @return string $content
     */
    public function getContent()
    {
        return $this->content;
    }

    /**
     * Sets the content
     *
     * @param string $content
     * @return void
     */
    public function setContent($content)
    {
        $this->content = $content;
    }

    /**
     * __construct
     */
    public function __construct()
    {

        //Do not remove the next line: It would break the functionality
        $this->initStorageObjects();
    }

    /**
     * Initializes all ObjectStorage properties
     * Do not modify this method!
     * It will be rewritten on each save in the extension builder
     * You may modify the constructor of this class instead
     *
     * @return void
     */
    protected function initStorageObjects()
    {
        $this->submenu = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
    }

    /**
     * Adds a Menu
     *
     * @param \NL\NlMenubuilder\Domain\Model\Menu $submenu
     * @return void
     */
    public function addSubmenu(\NL\NlMenubuilder\Domain\Model\Menu $submenu)
    {
        $this->submenu->attach($submenu);
    }

    /**
     * Removes a Menu
     *
     * @param \NL\NlMenubuilder\Domain\Model\Menu $submenuToRemove The Menu to be removed
     * @return void
     */
    public function removeSubmenu(\NL\NlMenubuilder\Domain\Model\Menu $submenuToRemove)
    {
        $this->submenu->detach($submenuToRemove);
    }

    /**
     * Returns the submenu
     *
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\Menu> $submenu
     */
    public function getSubmenu()
    {
        return $this->submenu->current();
    }

    /**
     * Sets the submenu
     *
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\NL\NlMenubuilder\Domain\Model\Menu> $submenu
     * @return void
     */
    public function setSubmenu(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $submenu)
    {
        $this->submenu = $submenu;
    }
}
